import user from './user' // eslint-disable-line
import { asyncRoutes, constantRoutes } from '@/router'
import { fetchUserPermissions, fetchUserRouters } from '@/api/permissions/index'
import { filterAsyncRouter } from '@/utils/permission'

const state = {
  routes: constantRoutes,
  addRoutes: [],
  permissions: [],
  userMenus: []
}

const mutations = {
  SET_ROUTES: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
  },
  SET_PERMISSIONS: (state, ps) => {
    state.permissions = ps
  }
}

const actions = {
  GetPermissions({ commit }, data) {
    return new Promise((resolve, reject) => {
      fetchUserPermissions().then(res => {
        commit('SET_PERMISSIONS', res)
        resolve(res)
      }).catch(error => {
        reject(error)
      })
    })
  },
  GenerateRoutes({ commit, dispatch }, data) {
    return new Promise((resolve, reject) => {
      fetchUserRouters().then(data => {
        const menus = data
        state.userMenus = menus
        // let accessedRouters
        if (state.userMenus && state.userMenus.length === 0) {
          commit('SET_ROUTES', [])
          resolve()
          return
        }
        const accessedRouters = filterAsyncRouter(asyncRoutes, menus)
        commit('SET_ROUTES', accessedRouters)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
